pub fn build_default_mcp_servers(config: &LoadedConfig) -> Vec<McpServer>Expand description
Default MCP server list — the client uses this array during session startup to build the session-level MCP factory.
pub fn build_default_mcp_servers(config: &LoadedConfig) -> Vec<McpServer>Default MCP server list — the client uses this array during session startup to build the session-level MCP factory.