Maps a SandboxMode to a concrete SandboxPolicy instance.
Functions
- build_
mode_ catalog - All sandbox modes in a fixed display order (read-only โ ask-writes โ open โ deny-all).
currentmarks the currently selected item, mapping to the ACPSessionModeState. - build_
policy - Selects the policy implementation based on
[sandbox].mode.